package com.autocareai.mvvmdemo.common.http

import com.autocareai.lib.net.observable.HttpObservable
import com.autocareai.lib.net.observable.HttpObservableImpl
import com.autocareai.lib.net.request.BaseRequest
import com.autocareai.mvvmdemo.common.tool.HttpTool

/**
 * <pre>
 *     author : Taylor Zhang
 *     time   : 2020/06/24
 *     desc   : 网络请求基类扩展
 *     version: 1.0.0
 * </pre>
 */

/**
 * 将Http响应数据转换成一个对象，去除最外层封装
 */
inline fun <reified D : Any> BaseRequest<*>.asResponse(): HttpObservable<D> {
    return HttpObservableImpl(this, ResponseConverter(D::class.java))
}

/**
 * 将Http响应数据转换成一个列表，去除最外层封装
 *
 * @param isAuth 是否需要添加认证参数，默认是true。
 */
inline fun <reified D : Any> BaseRequest<*>.asResponseList(): HttpObservable<ArrayList<D>> {
    return HttpObservableImpl(this, ResponseListConverter(D::class.java))
}
